Torfy Changelog
===============

For more information, check the README.md in <http://github.com/i3visio/torfy>.

0.1.0, 2016/03/01 -- Initial release.
- Added conectivity to a running instance of Tor Browser.
- Added configuration files with connection details.
- Added preprocessing of the response grabbed from the Tor Browser: domain, timestamp, headers, HTTP response and content are processed.
- Added two scripts that can be launched via the terminal: onionGet.py and onionsFromFile.py.
- Added basic documentation documents.
- Creation of the main modules.

